==> weixin2-1.0.15.jar: filiale/yuncheng/sqls/balanceRemind.sql <==
SELECT
    f_open_id,
    convert(varchar,f_balance) f_balance,
    f_userinfo_id,
    f_userfiles_id,
    f_user_name,
    f_meternumber,
    f_time,
    f_userinfo_code,
    f_orgid,
    convert(varchar,f_meter_base) f_meter_base,
    SUBSTRING(f_address,1,20) f_address
FROM (
     SELECT
         b.f_open_id,
         b.f_band_state,
         f_user_state,
         f_table_state,
         convert(decimal(18,2), CASE WHEN uf.f_meter_classify = '物联网表' THEN case when gb.f_calculation = '表端结算'  then isnull(m.f_jval,0) else isnull(f_balance_amount,0) end ELSE ui.f_balance END) f_balance,
         ui.f_userinfo_id,
         uf.f_userfiles_id,
         ui.f_user_name,
         uf.f_meternumber,
         CONVERT(varchar,GETDATE(),120) f_time,
         ui.f_userinfo_code,
         ui.f_orgid,
         uf.f_meter_base,
         ua.f_address
     FROM
         t_banduser b with(nolock)
         LEFT JOIN t_userinfo ui with(nolock) on ui.f_userinfo_id = b.f_userinfo_id
         LEFT JOIN t_userfiles uf with(nolock) ON ui.f_userinfo_id = uf.f_userinfo_id
         LEFT JOIN t_gasbrand gb on uf.f_gasbrand_id = gb.id
         LEFT JOIN t_meteread m with(nolock) on m.id = uf.f_meteread_maxid
         left join t_user_address ua with(nolock) on ui.f_userinfo_id = ua.f_userinfo_id
     where uf.f_meter_classify IN ('机表', '物联网表') and uf.f_user_type = '民用' and f_band_state = '有效' and f_user_state = '正常' and f_table_state = '正常' and isnull(uf.f_balance_pushed,'') != '1'
 ) c where {condition}  and f_balance <= 15

==> weixin2-1.0.30.jar: filiale/yuncheng/sqls/balanceRemind.sql <==
SELECT
    f_open_id,
    convert(varchar,f_balance) f_balance,
    f_userinfo_id,
    f_userfiles_id,
    f_user_name,
    f_meternumber,
    f_time,
    f_userinfo_code,
    f_orgid,
    convert(varchar,f_meter_base) f_meter_base,
    SUBSTRING(f_address,1,20) f_address
FROM (
     SELECT
         b.f_open_id,
         b.f_band_state,
         f_user_state,
         f_table_state,
         convert(decimal(18,2), CASE WHEN uf.f_meter_classify = '物联网表' THEN case when gb.f_calculation = '表端结算'  then isnull(m.f_jval,0) else isnull(f_balance_amount,0) end ELSE ui.f_balance END) f_balance,
         ui.f_userinfo_id,
         uf.f_userfiles_id,
         ui.f_user_name,
         uf.f_meternumber,
         CONVERT(varchar,GETDATE(),120) f_time,
         ui.f_userinfo_code,
         ui.f_orgid,
         uf.f_meter_base,
         ua.f_address,
         case when sl.f_delivery_date > tp.f_create_date or tp.f_create_date is null then 1 else 0 end ispush
     FROM
         t_banduser b with(nolock)
         LEFT JOIN t_userinfo ui with(nolock) on ui.f_userinfo_id = b.f_userinfo_id
         LEFT JOIN t_userfiles uf with(nolock) ON ui.f_userinfo_id = uf.f_userinfo_id
         LEFT JOIN t_gasbrand gb on uf.f_gasbrand_id = gb.id
         LEFT JOIN t_meteread m with(nolock) on m.id = uf.f_meteread_maxid
         left join t_user_address ua with(nolock) on ui.f_userinfo_id = ua.f_userinfo_id
         left join (
            select f_userfiles_id,max(f_operate_date) f_delivery_date  from t_sellinggas group by f_userfiles_id
         ) sl on sl.f_userfiles_id = uf.f_userfiles_id
         left join (
            select f_userfiles_id, max(f_create_date) f_create_date from t_template_push where f_send_type in  ('余额不足提醒','余额提醒')  group by f_userfiles_id
         ) tp on tp.f_userfiles_id = uf.f_userfiles_id
     where uf.f_meter_classify IN ('机表', '物联网表') and uf.f_user_type = '民用' and f_band_state = '有效' and f_user_state = '正常' and f_table_state = '正常'
 ) c where {condition} and f_balance <= 15 and ispush = 1
